==> ring_20190811.2.6131086.tar.gz: ring-project/lrc/translations/lrc_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Io</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>Parlando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>ERRORE</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>In arrivo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>Chiamando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>Connessione in corso </translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Comunicazione stabilita</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1268"/>
        <location filename="../src/conversationmodel.cpp" line="1657"/>
        <location filename="../src/conversationmodel.cpp" line="1917"/>
        <source>Invitation received</source>
        <translation>Invito ricevuto</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1269"/>
        <source>Contact added</source>
        <translation>Contatto aggiunto</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1311"/>
        <location filename="../src/conversationmodel.cpp" line="1318"/>
        <source>Invitation accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1528"/>
        <source>ð Outgoing call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1530"/>
        <source>ð Incoming call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1543"/>
        <source>ð Outgoing call - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1546"/>
        <source>ð Incoming call - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1550"/>
        <source>ð½ Missed outgoing call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1552"/>
        <source>ð½ Missed incoming call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="311"/>
        <location filename="../src/avmodel.cpp" line="332"/>
        <source>default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="45"/>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="46"/>
        <source>Trying</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="47"/>
        <source>Ringing</source>
        <translation>Suonando</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Being Forwarded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Queued</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Progress</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Multiple Choices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>Moved Permanently</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Moved Temporarily</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Use Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Alternative Service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Bad Request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Unauthorized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Payment Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Forbidden</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Not Found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Method Not Allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Not Acceptable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Proxy Authentication Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Request Timeout</source>
        <translation>Richiedi Timeout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Gone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Request Entity Too Large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request URI Too Long</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Unsupported Media Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Unsupported URI Scheme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Bad Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Extension Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Session Timer Too Small</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Interval Too Brief</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Temporarily Unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Call TSX Does Not Exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Loop Detected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Too Many Hops</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Address Incomplete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Ambiguous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Request Terminated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Bad Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Request Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Undecipherable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Internal Server Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Not Implemented</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Bad Gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Service Unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Server Timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Version Not Supported</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Message Too Large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Precondition Failure</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Busy Everywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Call Refused</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Does Not Exist Anywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Acceptable Anywhere</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="403"/>
        <source>Searchingâ¦</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="760"/>
        <source>Invalid ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="763"/>
        <source>Not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="766"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="374"/>
        <source>Bad URI scheme</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> ring_20190928.1.a9762b9.tar.gz: ring-project/lrc/translations/lrc_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Io</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>Parlando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>ERRORE</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>In arrivo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>Chiamando</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>Connessione in corso </translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Comunicazione stabilita</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="135"/>
        <location filename="../src/authority/storagehelper.cpp" line="856"/>
        <source>Invitation received</source>
        <translation>Invito ricevuto</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="132"/>
        <location filename="../src/authority/storagehelper.cpp" line="854"/>
        <source>Contact added</source>
        <translation>Contatto aggiunto</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="106"/>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="852"/>
        <source>Outgoing call</source>
        <translation>Chiamata in uscita</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="108"/>
        <location filename="../src/authority/storagehelper.cpp" line="119"/>
        <source>Incoming call</source>
        <translation>Chiamata in arrivo</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="115"/>
        <location filename="../src/authority/storagehelper.cpp" line="850"/>
        <source>Missed outgoing call</source>
        <translation>Chiamata in uscita persa</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Missed incoming call</source>
        <translation>Chiamata in entrata persa</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="137"/>
        <location filename="../src/authority/storagehelper.cpp" line="858"/>
        <source>Invitation accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="312"/>
        <location filename="../src/avmodel.cpp" line="333"/>
        <source>default</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="46"/>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="47"/>
        <source>Trying</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Ringing</source>
        <translation>Suonando</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Being Forwarded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Queued</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>Progress</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>Multiple Choices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Moved Permanently</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Moved Temporarily</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Use Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Alternative Service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Bad Request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Unauthorized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Payment Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Forbidden</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Not Found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Method Not Allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Not Acceptable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Proxy Authentication Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Request Timeout</source>
        <translation>Richiedi Timeout</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Gone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request Entity Too Large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Request URI Too Long</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Unsupported Media Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Unsupported URI Scheme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Bad Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Extension Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Session Timer Too Small</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Interval Too Brief</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Temporarily Unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Call TSX Does Not Exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Loop Detected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Too Many Hops</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Address Incomplete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Ambiguous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Request Terminated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Bad Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Request Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Request Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Undecipherable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Internal Server Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Not Implemented</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Bad Gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Service Unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Server Timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Version Not Supported</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Message Too Large</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Precondition Failure</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Busy Everywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Call Refused</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Does Not Exist Anywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Not Acceptable Anywhere</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="405"/>
        <source>Searchingâ¦</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="765"/>
        <source>Invalid ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="768"/>
        <source>Registered name not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="771"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="371"/>
        <source>Bad URI scheme</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
